"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.qDependencies = exports.qLongFormDep = void 0;
const good_enough_parser_1 = require("good-enough-parser");
const regex_1 = require("../../../../util/regex");
const common_1 = require("./common");
const handlers_1 = require("./handlers");
// "foo:bar:1.2.3"
const qDependenciesSimpleString = common_1.qStringValue
    .handler((ctx) => (0, common_1.storeInTokenMap)(ctx, 'stringToken'))
    .handler(handlers_1.handleDepSimpleString)
    .handler(common_1.cleanupTempVars);
// "foo:bar:$baz"
const qDependenciesInterpolation = common_1.qTemplateString
    .handler((ctx) => (0, common_1.storeInTokenMap)(ctx, 'templateStringTokens'))
    .handler(handlers_1.handleDepInterpolation)
    .handler(common_1.cleanupTempVars);
// dependencySet(group: 'foo', version: bar) { entry 'baz' }
const qDependencySet = good_enough_parser_1.query
    .sym('dependencySet', common_1.storeVarToken)
    .handler((ctx) => (0, common_1.storeInTokenMap)(ctx, 'methodName'))
    .tree({
    type: 'wrapped-tree',
    maxDepth: 1,
    startsWith: '(',
    endsWith: ')',
    search: good_enough_parser_1.query
        .begin()
        .sym('group')
        .alt(good_enough_parser_1.query.op(':'), good_enough_parser_1.query.op('='))
        .alt(common_1.qTemplateString, common_1.qVariableAccessIdentifier)
        .handler((ctx) => (0, common_1.storeInTokenMap)(ctx, 'groupId'))
        .op(',')
        .sym('version')
        .alt(good_enough_parser_1.query.op(':'), good_enough_parser_1.query.op('='))
        .alt(common_1.qTemplateString, common_1.qVariableAccessIdentifier)
        .handler((ctx) => (0, common_1.storeInTokenMap)(ctx, 'version'))
        .end(),
})
    .tree({
    type: 'wrapped-tree',
    maxDepth: 1,
    startsWith: '{',
    endsWith: '}',
    search: good_enough_parser_1.query
        .sym('entry')
        .alt(common_1.qTemplateString, common_1.qVariableAccessIdentifier, good_enough_parser_1.query.tree({
        type: 'wrapped-tree',
        maxDepth: 1,
        startsWith: '(',
        endsWith: ')',
        search: good_enough_parser_1.query
            .begin()
            .alt(common_1.qTemplateString, common_1.qVariableAccessIdentifier)
            .end(),
    }))
        .handler((ctx) => (0, common_1.storeInTokenMap)(ctx, 'artifactId'))
        .handler(handlers_1.handleLongFormDep),
})
    .handler(common_1.cleanupTempVars);
// group: "foo", name: "bar", version: "1.2.3"
const qGroovyMapNotationDependencies = good_enough_parser_1.query
    .sym('group')
    .op(':')
    .alt(common_1.qTemplateString, common_1.qVariableAccessIdentifier)
    .handler((ctx) => (0, common_1.storeInTokenMap)(ctx, 'groupId'))
    .op(',')
    .sym('name')
    .op(':')
    .alt(common_1.qTemplateString, common_1.qVariableAccessIdentifier)
    .handler((ctx) => (0, common_1.storeInTokenMap)(ctx, 'artifactId'))
    .op(',')
    .sym('version')
    .op(':')
    .alt(common_1.qTemplateString, common_1.qVariableAccessIdentifier)
    .handler((ctx) => (0, common_1.storeInTokenMap)(ctx, 'version'))
    .handler(handlers_1.handleLongFormDep)
    .handler(common_1.cleanupTempVars);
// kotlin("bom", "1.7.21")
const qKotlinShortNotationDependencies = good_enough_parser_1.query
    .sym('kotlin')
    .tree({
    type: 'wrapped-tree',
    maxDepth: 1,
    startsWith: '(',
    endsWith: ')',
    search: good_enough_parser_1.query
        .begin()
        .alt(common_1.qTemplateString, common_1.qVariableAccessIdentifier)
        .handler((ctx) => (0, common_1.storeInTokenMap)(ctx, 'moduleName'))
        .op(',')
        .opt(good_enough_parser_1.query.sym('version').op('='))
        .alt(common_1.qTemplateString, common_1.qPropertyAccessIdentifier, common_1.qVariableAccessIdentifier)
        .handler((ctx) => (0, common_1.storeInTokenMap)(ctx, 'version'))
        .end(),
})
    .handler(handlers_1.handleKotlinShortNotationDep)
    .handler(common_1.cleanupTempVars);
// (group = "foo", name = "bar", version = "1.2.3")
const qKotlinMapNotationDependencies = good_enough_parser_1.query
    .tree({
    type: 'wrapped-tree',
    maxDepth: 1,
    startsWith: '(',
    endsWith: ')',
    search: good_enough_parser_1.query
        .begin()
        .sym('group')
        .op('=')
        .alt(common_1.qTemplateString, common_1.qVariableAccessIdentifier)
        .handler((ctx) => (0, common_1.storeInTokenMap)(ctx, 'groupId'))
        .op(',')
        .sym('name')
        .op('=')
        .alt(common_1.qTemplateString, common_1.qVariableAccessIdentifier)
        .handler((ctx) => (0, common_1.storeInTokenMap)(ctx, 'artifactId'))
        .op(',')
        .sym('version')
        .op('=')
        .alt(common_1.qTemplateString, common_1.qVariableAccessIdentifier)
        .handler((ctx) => (0, common_1.storeInTokenMap)(ctx, 'version')),
})
    .handler(handlers_1.handleLongFormDep)
    .handler(common_1.cleanupTempVars);
// someMethod("foo", "bar", "1.2.3")
exports.qLongFormDep = good_enough_parser_1.query
    .opt(good_enough_parser_1.query.sym(common_1.storeVarToken).handler((ctx) => (0, common_1.storeInTokenMap)(ctx, 'methodName')))
    .tree({
    type: 'wrapped-tree',
    maxDepth: 1,
    maxMatches: 1,
    startsWith: '(',
    endsWith: ')',
    search: good_enough_parser_1.query
        .begin()
        .alt(common_1.qTemplateString, common_1.qVariableAccessIdentifier)
        .handler((ctx) => (0, common_1.storeInTokenMap)(ctx, 'groupId'))
        .op(',')
        .alt(common_1.qTemplateString, common_1.qVariableAccessIdentifier)
        .handler((ctx) => (0, common_1.storeInTokenMap)(ctx, 'artifactId'))
        .op(',')
        .alt(common_1.qTemplateString, common_1.qVariableAccessIdentifier)
        .handler((ctx) => (0, common_1.storeInTokenMap)(ctx, 'version'))
        .end(),
})
    .handler(handlers_1.handleLongFormDep)
    .handler(common_1.cleanupTempVars);
// pmd { toolVersion = "1.2.3" }
const qImplicitGradlePlugin = good_enough_parser_1.query
    .sym((0, regex_1.regEx)(`^(?:${Object.keys(common_1.GRADLE_PLUGINS).join('|')})$`), common_1.storeVarToken)
    .handler((ctx) => (0, common_1.storeInTokenMap)(ctx, 'pluginName'))
    .tree({
    type: 'wrapped-tree',
    maxDepth: 1,
    maxMatches: 1,
    startsWith: '{',
    endsWith: '}',
    search: good_enough_parser_1.query
        .sym((0, regex_1.regEx)(/^(?:toolVersion|version)$/))
        .op('=')
        .alt(common_1.qTemplateString, common_1.qPropertyAccessIdentifier, common_1.qVariableAccessIdentifier),
})
    .handler((ctx) => (0, common_1.storeInTokenMap)(ctx, 'version'))
    .handler(handlers_1.handleImplicitGradlePlugin)
    .handler(common_1.cleanupTempVars);
exports.qDependencies = good_enough_parser_1.query.alt(qDependenciesSimpleString, qDependenciesInterpolation, qDependencySet, qGroovyMapNotationDependencies, qKotlinShortNotationDependencies, qKotlinMapNotationDependencies, qImplicitGradlePlugin);
//# sourceMappingURL=dependencies.js.map